#!/bin/sh -e

DIRNAME=`dirname $0`
cd $DIRNAME
USAGE="$0 [ --update ]"
if [ `id -u` != 0 ]; then
echo 'You must be root to run this script'
exit 1
fi

if [ $# -eq 1 ]; then
	if [ "$1" = "--update" ] ; then
		time=`ls -l --time-style="+%x %X" ipa.te | awk '{ printf "%s %s", $6, $7 }'`
		rules=`ausearch --start $time -m avc --raw -se ipa`
		if [ x"$rules" != "x" ] ; then
			echo "Found avc's to update policy with"
			echo -e "$rules" | audit2allow -R
			echo "Do you want these changes added to policy [y/n]?"
			read ANS
			if [ "$ANS" = "y" -o "$ANS" = "Y" ] ; then
				echo "Updating policy"
				echo -e "$rules" | audit2allow -R >> ipa.te
				# Fall though and rebuild policy
			else
				exit 0
			fi
		else
			echo "No new avcs found"
			exit 0
		fi
	else
		echo -e $USAGE
		exit 1
	fi
elif [ $# -ge 2 ] ; then
	echo -e $USAGE
	exit 1
fi

echo "Building and Loading Policy"
set -x
make -f /usr/share/selinux/devel/Makefile ipa.pp || exit
/usr/sbin/semodule -i ipa.pp

# Generate a man page off the installed module
#sepolicy manpage -p . -d ipa_t

# Generate a rpm package for the newly generated policy

pwd=$(pwd)
rpmbuild --define "_sourcedir ${pwd}" --define "_specdir ${pwd}" --define "_builddir ${pwd}" --define "_srcrpmdir ${pwd}" --define "_rpmdir ${pwd}" --define "_buildrootdir ${pwd}/.build"  -ba ipa_selinux.spec

# Fixing the file context on /usr/libexec/ipa-otpd
/sbin/restorecon -F -R -v /usr/libexec/ipa-otpd
# Fixing the file context on /usr/lib/systemd/system/ipa.service
#/sbin/restorecon -F -R -v /usr/lib/systemd/system/ipa.service
# Fixing the file context on /usr/lib/systemd/system/ipa-otpd@.service
/sbin/restorecon -F -R -v /usr/lib/systemd/system/ipa-otpd@.service
# Fixing the file context on /usr/lib/systemd/system/ipa_memcached.service
#/sbin/restorecon -F -R -v /usr/lib/systemd/system/ipa_memcached.service
# Fixing the file context on /usr/lib/systemd/system/ipa-otpd.socket
/sbin/restorecon -F -R -v /usr/lib/systemd/system/ipa-otpd.socket
# Fixing the file context on /var/cache/ipa
#/sbin/restorecon -F -R -v /var/cache/ipa
# Fixing the file context on /var/lib/ipa
#/sbin/restorecon -F -R -v /var/lib/ipa
# Fixing the file context on /var/run/ipa_memcached
#/sbin/restorecon -F -R -v /var/run/ipa_memcached
# Fixing the file context on /var/run/ipa
#/sbin/restorecon -F -R -v /var/run/ipa
